@@ -1,7 +1,9 @@
 #' @rdname before-and-after
 #' @export
 str_before_nth <- function(string, pattern, n) {
-  if (is_l0_char(string)) return(character())
+  if (is_l0_char(string)) {
+    return(character())
+  }
   verify_string_pattern_n(string, pattern, n)
   nth_instance_indices <- str_locate_nth(string, pattern, n)
   str_sub(string, 1, nth_instance_indices[, "start"] - 1)
@@ -31,11 +33,12 @@ str_before_last <- function(string, pattern) {
 #'
 #' @examples
 #' str_before_last_dot(c("spreadsheet1.csv", "doc2.doc", ".R"))
-#'
 #' @family bisectors
 #' @export
 str_before_last_dot <- function(string) {
-  if (is_l0_char(string)) return(character())
+  if (is_l0_char(string)) {
+    return(character())
+  }
   checkmate::assert_character(string)
   string %>%
     tools::file_path_sans_ext() %T>% {
